#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# original build script from Fred. Galusik <fredg> (fred~AT~zenwalk.fr)
# source location    : http://goodies.xfce.org/releases/ristretto/
# last revised       : 2.02.2010

softname='ristretto'
softversion='0.0.22'
packageversion='64.1'

arch='i486'
cpu='i686'

prefix=/usr

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://goodies.xfce.org/releases/ristretto/$softname-$softversion.tar.gz

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
         |-----handy-ruler------------------------------------------------------|
ristretto: ristretto - Picture-viewer
ristretto: 
ristretto: Ristretto is a fast and lightweight picture-viewer 
ristretto: for the Xfce desktop environment. 
ristretto: 
ristretto: 
ristretto: 
ristretto: 
ristretto: 
ristretto:
ristretto: 
EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src

# build

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=$prefix \
      --docdir=$prefix/doc/$softname-$softversion \
      --program-prefix="" \
      --program-suffix="" \
      --build=$arch-slackware-linux

    make
    make install DESTDIR=$dest

# add 'default' files
    cp -a \
      AUTHORS COPYING INSTALL README ChangeLog NEWS TODO \
      $dest/usr/doc/$softname-$softversion

# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "atk,dbus,dbus-glib,expat,fontconfig,freetype,gamin,glib2,\
gtk+2,hal,libexif,libjpeg,libpng,libusb,pango,startup-notification,\
xfce-apps,xfce-base,xorg-server,xcb-util,zlib" > $package.dep

# generate source file
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/ristretto/source/build-ristretto.sh > $package.src
echo $source >> $package.src


# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
